@@ -26,7 +26,6 @@ class AllergyCommand(BaseCommand):
 
     class Meta:
         key = "allergy"
-        commit_required_fields = ("allergy",)
 
     class Severity(Enum):
         MILD = "mild"
@@ -38,14 +37,9 @@ class AllergyCommand(BaseCommand):
     narrative: str | None = None
     approximate_date: date | None = None
 
-    @property
-    def values(self) -> dict:
-        """The Allergy command's field values."""
-        return {
-            "allergy": self.allergy,
-            "severity": self.severity.value if self.severity else None,
-            "narrative": self.narrative,
-            "approximate_date": (
-                self.approximate_date.isoformat() if self.approximate_date else None
-            ),
-        }
+
+__exports__ = (
+    "AllergenType",
+    "Allergen",
+    "AllergyCommand",
+)
