@@ -1,4 +1,5 @@
 from enum import Enum
+from uuid import UUID
 
 from pydantic import Field
 
@@ -10,30 +11,19 @@ class AssessCommand(_BaseCommand):
 
     class Meta:
         key = "assess"
-        commit_required_fields = ("condition_id",)
 
     class Status(Enum):
         IMPROVED = "improved"
         STABLE = "stable"
         DETERIORATED = "deteriorated"
 
-    condition_id: str | None = Field(
+    condition_id: UUID | str | None = Field(
         default=None, json_schema_extra={"commands_api_name": "condition"}
     )
     background: str | None = None
     status: Status | None = None
     narrative: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The Assess command's field values."""
-        return {
-            "condition_id": self.condition_id,
-            "background": self.background,
-            "status": self.status.value if self.status else None,
-            "narrative": self.narrative,
-        }
-
 
 # how do we make sure that condition_id is a valid condition for the patient?
 
@@ -50,3 +40,5 @@ class AssessCommand(_BaseCommand):
 
 # idea2:
 # validator that checks that condition.patient is the same as note.patient
+
+__exports__ = ("AssessCommand",)
