@@ -8,7 +8,6 @@ class RemoveAllergyCommand(BaseCommand):
 
     class Meta:
         key = "removeAllergy"
-        commit_required_fields = ("allergy_id",)
 
     allergy_id: str | None = Field(
         description="The external ID of the allergy to remove.",
@@ -17,10 +16,5 @@ class RemoveAllergyCommand(BaseCommand):
     )
     narrative: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The Remove Allergy command's field values."""
-        return {
-            "allergy_id": self.allergy_id,
-            "narrative": self.narrative,
-        }
+
+__exports__ = ("RemoveAllergyCommand",)
