@@ -15,6 +15,8 @@ from .coverage import Coverage, Transactor, TransactorAddress, TransactorPhone
 from .detected_issue import DetectedIssue, DetectedIssueEvidence
 from .device import Device
 from .discount import Discount
+from .facility import Facility
+from .goal import Goal
 from .imaging import ImagingOrder, ImagingReport, ImagingReview
 from .invoice import Invoice
 from .lab import (
@@ -50,6 +52,7 @@ from .patient import (
     PatientAddress,
     PatientContactPoint,
     PatientExternalIdentifier,
+    PatientFacilityAddress,
     PatientMetadata,
     PatientSetting,
 )
@@ -68,6 +71,7 @@ from .posting import (
     PatientPosting,
 )
 from .practicelocation import PracticeLocation, PracticeLocationSetting
+from .protocol_current import ProtocolCurrent
 from .protocol_override import ProtocolOverride
 from .questionnaire import (
     Interview,
@@ -80,7 +84,9 @@ from .questionnaire import (
     ResponseOptionSet,
 )
 from .reason_for_visit import ReasonForVisitSettingCoding
-from .staff import Staff, StaffAddress, StaffContactPoint, StaffPhoto
+from .referral import Referral, ReferralReport
+from .service_provider import ServiceProvider
+from .staff import Staff, StaffAddress, StaffContactPoint, StaffLicense, StaffPhoto, StaffRole
 from .task import Task, TaskComment, TaskLabel, TaskTaskLabel
 from .team import Team, TeamContactPoint
 from .user import CanvasUser
@@ -118,6 +124,8 @@ __all__ = __exports__ = (
     "DetectedIssueEvidence",
     "Device",
     "Discount",
+    "Facility",
+    "Goal",
     "ImagingOrder",
     "ImagingReport",
     "ImagingReview",
@@ -157,6 +165,7 @@ __all__ = __exports__ = (
     "PatientAddress",
     "PatientContactPoint",
     "PatientExternalIdentifier",
+    "PatientFacilityAddress",
     "PatientPosting",
     "PatientSetting",
     "PatientMetadata",
@@ -167,16 +176,22 @@ __all__ = __exports__ = (
     "PaymentCollection",
     "PracticeLocation",
     "PracticeLocationSetting",
+    "ProtocolCurrent",
     "ProtocolOverride",
     "Question",
     "Questionnaire",
     "QuestionnaireQuestionMap",
     "ReasonForVisitSettingCoding",
+    "Referral",
+    "ReferralReport",
     "ResponseOption",
     "ResponseOptionSet",
+    "ServiceProvider",
     "Staff",
     "StaffAddress",
+    "StaffLicense",
     "StaffPhoto",
+    "StaffRole",
     "StaffContactPoint",
     "Task",
     "TaskComment",
