@@ -4,6 +4,7 @@ import ast
 import builtins
 import importlib
 import json
+import operator
 import sys
 import types
 from _ast import AnnAssign
@@ -196,6 +197,8 @@ THIRD_PARTY_MODULES = {
         "BigIntegerField",
         "Case",
         "CharField",
+        "Count",
+        "F",
         "IntegerField",
         "Model",  # remove when hyperscribe no longer needs it
         "Q",
@@ -222,9 +225,11 @@ THIRD_PARTY_MODULES = {
     },
     "pydantic": {
         "BaseModel",
+        "ConfigDict",
         "conint",
         "constr",
         "Field",
+        "RootModel",
         "ValidationError",
     },
     "rapidfuzz": {
@@ -264,6 +269,34 @@ def _unrestricted(_ob: Any, *args: Any, **kwargs: Any) -> Any:
     return _ob
 
 
+def _inplacevar(op: Any, val: Any, expr: Any) -> Any:
+    """
+    Apply the specified operation to the value and expression.
+
+    NOTE: Does not yet support += concatenation for sequences.
+    """
+    ops = {
+        "-=": operator.isub,
+        "@=": operator.imatmul,
+        "**=": operator.ipow,
+        "*=": operator.imul,
+        "//=": operator.ifloordiv,
+        "/=": operator.itruediv,
+        "&=": operator.iand,
+        "%=": operator.imod,
+        "^=": operator.ixor,
+        "+=": operator.iadd,
+        "<<=": operator.ilshift,
+        ">>=": operator.irshift,
+        "|=": operator.ior,
+    }
+
+    if op not in ops:
+        raise ValueError(f"Invalid inplace operation: {op}")
+
+    return ops[op](val, expr)
+
+
 def _apply(_ob: Any, *args: Any, **kwargs: Any) -> Any:
     """Call the bound method with args, support calling super().__init__()."""
     return _ob(*args, **kwargs)
@@ -614,6 +647,7 @@ class Sandbox:
                 "dict": builtins.dict,
                 "enumerate": builtins.enumerate,
                 "filter": builtins.filter,
+                "getattr": self._safe_getattr,
                 "hasattr": builtins.hasattr,
                 "iter": builtins.iter,
                 "list": builtins.list,
@@ -634,7 +668,7 @@ class Sandbox:
             "_getattr_": self._safe_getattr,
             "_getitem_": self._safe_getitem,
             "_getiter_": _unrestricted,
-            "_inplacevar_": _unrestricted,
+            "_inplacevar_": _inplacevar,
             "_iter_unpack_sequence_": guarded_iter_unpack_sequence,
             "_print_": PrintCollector,
             "_unpack_sequence_": guarded_unpack_sequence,
